@@ -3,6 +3,7 @@ from .aws_base import get_aiosession
 from .aws_lambda import invoke as lambda_invoke
 from .aws_queue import Queue
 from .aws_metadata import get_instance_id
-from .s3 import STATE_NOT_EXISTING, STATE_OK, STATE_PRECONDITION_FAILED, S3Bucket
+from .s3 import STATE_NOT_EXISTING, STATE_OK, STATE_PRECONDITION_FAILED, S3Bucket, VersionedS3Bucket
 from .secret_manager import get_secret, get_secret_parser
 from .sns import Topic
+from .aws_logs import Logs, CloudWatchLogEvent, CloudWatchFilteredLogEvent
